@@ -1,12 +1,11 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -34,12 +33,12 @@ import org.junit.rules.TestName;
 
 public class TestH5Obasic {
     @Rule public TestName testname = new TestName();
-    private static final String H5_FILE = "h5ex_g_iterate.hdf";
+    private static final String H5_FILE = "h5ex_g_iterateO1.hdf";
     private static long H5la_ds1 = -1;
     private static long H5la_l1 = -1;
     private static long H5la_dt1 = -1;
     private static long H5la_g1 = -1;
-    long H5fid = -1;
+    long H5fid = HDF5Constants.H5I_INVALID_HID;
 
     @Before
     public void openH5file()
@@ -67,7 +66,7 @@ public class TestH5Obasic {
 
     @Test(expected = HDF5LibraryException.class)
     public void testH5Oopen_not_exists() throws Throwable {
-        long oid = -1;
+        long oid = HDF5Constants.H5I_INVALID_HID;
 
         oid = H5.H5Oopen(H5fid, "Never_created", HDF5Constants.H5P_DEFAULT);
 
@@ -76,7 +75,7 @@ public class TestH5Obasic {
 
     @Test
     public void testH5Oget_info_dataset() {
-        long oid = -1;
+        long oid = HDF5Constants.H5I_INVALID_HID;
         H5O_info_t obj_info = null;
 
         try {
@@ -94,7 +93,7 @@ public class TestH5Obasic {
 
     @Test
     public void testH5Oget_info_hardlink() {
-        long oid = -1;
+        long oid = HDF5Constants.H5I_INVALID_HID;
         H5O_info_t obj_info = null;
         try {
             oid = H5.H5Oopen(H5fid, "L1", HDF5Constants.H5P_DEFAULT);
@@ -111,7 +110,7 @@ public class TestH5Obasic {
 
     @Test
     public void testH5Oget_info_group() {
-        long oid = -1;
+        long oid = HDF5Constants.H5I_INVALID_HID;
         H5O_info_t obj_info = null;
         try {
             oid = H5.H5Oopen(H5fid, "G1", HDF5Constants.H5P_DEFAULT);
@@ -128,7 +127,7 @@ public class TestH5Obasic {
 
     @Test
     public void testH5Oget_info_datatype() {
-        long oid = -1;
+        long oid = HDF5Constants.H5I_INVALID_HID;
         H5O_info_t obj_info = null;
         try {
             oid = H5.H5Oopen(H5fid, "DT1", HDF5Constants.H5P_DEFAULT);
@@ -258,7 +257,7 @@ public class TestH5Obasic {
 
     @Test
     public void testH5Oget_info_by_idx_n3() {
-        long oid = -1;
+        long oid = HDF5Constants.H5I_INVALID_HID;
         H5O_info_t obj_info = null;
         try {
             oid = H5.H5Oopen(H5fid, "L1", HDF5Constants.H5P_DEFAULT);
@@ -410,7 +409,7 @@ public class TestH5Obasic {
 
     @Test
     public void testH5Oopen_by_idx_n0() {
-        long oid = -1;
+        long oid = HDF5Constants.H5I_INVALID_HID;
         H5O_info_t obj_info = null;
         try {
             try {
@@ -448,7 +447,7 @@ public class TestH5Obasic {
 
     @Test
     public void testH5Oopen_by_idx_n3() {
-        long oid = -1;
+        long oid = HDF5Constants.H5I_INVALID_HID;
         H5O_info_t obj_info = null;
         try {
             try {
