@@ -6,7 +6,7 @@
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -33,13 +33,13 @@
 
 #ifdef H5_HAVE_THREADSAFE
 
-#define NUM_THREAD              16
-#define FILENAME                "ttsafe_error.h5"
+#define NUM_THREAD 16
+#define FILENAME   "ttsafe_error.h5"
 
 /* Having a common dataset name is an error */
-#define DATASETNAME             "commonname"
-#define EXPECTED_ERROR_DEPTH	7
-#define WRITE_NUMBER            37
+#define DATASETNAME          "commonname"
+#define EXPECTED_ERROR_DEPTH 7
+#define WRITE_NUMBER         37
 
 /* Typedefs */
 typedef struct err_num_struct {
@@ -48,26 +48,25 @@ typedef struct err_num_struct {
 } err_num_t;
 
 /* Global variables */
-hid_t               error_file_g    = H5I_INVALID_HID;
-int                 error_flag_g    = 0;
-int                 error_count_g   = 0;
+hid_t               error_file_g  = H5I_INVALID_HID;
+int                 error_flag_g  = 0;
+int                 error_count_g = 0;
 err_num_t           expected_g[EXPECTED_ERROR_DEPTH];
 H5TS_mutex_simple_t error_mutex_g;
 
 /* Prototypes */
-static herr_t error_callback(hid_t , void *);
+static herr_t error_callback(hid_t, void *);
 static herr_t walk_error_callback(unsigned, const H5E_error2_t *, void *);
-static void *tts_error_thread(void *);
-
+static void * tts_error_thread(void *);
 
 void
 tts_error(void)
 {
-    hid_t           dataset = H5I_INVALID_HID;
-    H5TS_thread_t   threads[NUM_THREAD];
-    H5TS_attr_t     attribute;
-    int             value, i;
-    herr_t          status;
+    hid_t         dataset = H5I_INVALID_HID;
+    H5TS_thread_t threads[NUM_THREAD];
+    H5TS_attr_t   attribute;
+    int           value, i;
+    herr_t        status;
 
     /* Must initialize these at runtime */
     expected_g[0].maj_num = H5E_DATASET;
@@ -120,7 +119,7 @@ tts_error(void)
     }
 
     if (error_count_g != NUM_THREAD - 1)
-        TestErrPrintf("Error: %d threads failed instead of %d\n", error_count_g, NUM_THREAD-1);
+        TestErrPrintf("Error: %d threads failed instead of %d\n", error_count_g, NUM_THREAD - 1);
 
     dataset = H5Dopen2(error_file_g, DATASETNAME, H5P_DEFAULT);
     CHECK(dataset, H5I_INVALID_HID, "H5Dopen2");
@@ -142,14 +141,14 @@ tts_error(void)
 static void *
 tts_error_thread(void H5_ATTR_UNUSED *arg)
 {
-    hid_t   dataspace   = H5I_INVALID_HID;
-    hid_t   datatype    = H5I_INVALID_HID;
-    hid_t   dataset     = H5I_INVALID_HID;
-    hsize_t dimsf[1]; /* dataset dimensions */
+    hid_t       dataspace = H5I_INVALID_HID;
+    hid_t       datatype  = H5I_INVALID_HID;
+    hid_t       dataset   = H5I_INVALID_HID;
+    hsize_t     dimsf[1]; /* dataset dimensions */
     H5E_auto2_t old_error_cb;
-    void *old_error_client_data;
-    int value;
-    herr_t status;
+    void *      old_error_client_data;
+    int         value;
+    herr_t      status;
 
     /* preserve previous error stack handler */
     status = H5Eget_auto2(H5E_DEFAULT, &old_error_cb, &old_error_client_data);
@@ -160,7 +159,7 @@ tts_error_thread(void H5_ATTR_UNUSED *arg)
     CHECK(status, FAIL, "H5Eset_auto2");
 
     /* define dataspace for dataset */
-    dimsf[0] = 1;
+    dimsf[0]  = 1;
     dataspace = H5Screate_simple(1, dimsf, NULL);
     CHECK(dataspace, H5I_INVALID_HID, "H5Screate_simple");
 
@@ -171,10 +170,11 @@ tts_error_thread(void H5_ATTR_UNUSED *arg)
     CHECK(status, FAIL, "H5Tset_order");
 
     /* create a new dataset within the file */
-    dataset = H5Dcreate2(error_file_g, DATASETNAME, datatype, dataspace, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
+    dataset =
+        H5Dcreate2(error_file_g, DATASETNAME, datatype, dataspace, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
     /* Most of these will fail, so don't check the error here */
     if (dataset >= 0) {
-        value = WRITE_NUMBER;
+        value  = WRITE_NUMBER;
         status = H5Dwrite(dataset, H5T_NATIVE_INT, H5S_ALL, H5S_ALL, H5P_DEFAULT, &value);
         CHECK(status, FAIL, "H5Dwrite");
         status = H5Dclose(dataset);
@@ -205,8 +205,8 @@ error_callback(hid_t H5_ATTR_UNUSED estack_id, void *client_data)
 static herr_t
 walk_error_callback(unsigned n, const H5E_error2_t *err_desc, void H5_ATTR_UNUSED *client_data)
 {
-    hid_t   maj_num = H5I_INVALID_HID;
-    hid_t   min_num = H5I_INVALID_HID;
+    hid_t maj_num = H5I_INVALID_HID;
+    hid_t min_num = H5I_INVALID_HID;
 
     if (err_desc) {
         maj_num = err_desc->maj_num;
@@ -217,6 +217,7 @@ walk_error_callback(unsigned n, const H5E_error2_t *err_desc, void H5_ATTR_UNUSE
     }
 
     error_flag_g = -1;
+
     return SUCCEED;
 }
 
@@ -227,4 +228,3 @@ cleanup_error(void)
 }
 
 #endif /*H5_HAVE_THREADSAFE*/
-
